@@ -254,11 +254,14 @@ class Radiko():
          f.write(audio)
 
    def getLiveStationStreamUrls(self, station):
+      streambase_response = requests.get(STREAM_BASE + station + ".xml")
+      streambase_list = ET.fromstring(streambase_response.text)
+      streamUrl = streambase_list[0][0].text
       a_exp = hashlib.md5(str(math.floor(random.random() * 1000000000) + math.floor(time.time())).encode()).hexdigest()
       stream_headers = {
          "X-Radiko-AuthToken": self.authToken
       }
-      stream_response = requests.get(STREAM_BASE + "?station_id=" + station + "&l=15&lsid=" + a_exp + "&type=b", headers=stream_headers)
+      stream_response = requests.get(streamUrl + "?station_id=" + station + "&l=15&lsid=" + a_exp + "&type=b", headers=stream_headers)
       stream_response.encoding = "UTF-8"
       if stream_response.status_code != requests.codes.ok:
          raise RadikoException("Failed to get playlist")
